<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 09/14/2008 *
 * ===============                              Last change: 09/14/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : purge-inactive.php                               *
 * -------------------------------------------------------------------- *
 * Short description : Purge of inactive users                          *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auto-Loeschung von inaktiven Mitgliedern         *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} // END - if

// Abort if autopurge is not active or disabled by admin
if ((!EXT_IS_ACTIVE("autopurge")) || (getConfig('auto_purge_active') == "N")) {
	// Abort here
	return false;
} // END - if

// Shall I look for inactive accounts and autopurge inactive accounts?
if (getConfig('autopurge_inactive') == "Y") {
	// Ok, let's have a look...
	$since = bigintval(getConfig('ap_inactive_since'));

	// Init exclusion list
	$EXCLUDE_LIST = "";
	if (getConfig('def_refid') > 0) {
		$EXCLUDE_LIST = " AND d.userid != ".getConfig('def_refid');
	} // END - if

	// Check for more extensions
	if (EXT_IS_ACTIVE("beg"))     $EXCLUDE_LIST .= " AND d.userid != ".getConfig('beg_uid')."";
	if (EXT_IS_ACTIVE("bonus"))   $EXCLUDE_LIST .= " AND d.userid != ".getConfig('bonus_uid')."";
	if (EXT_IS_ACTIVE("doubler")) $EXCLUDE_LIST .= " AND d.userid != ".getConfig('doubler_uid')."";

	// Check for new holiday extension
	if (GET_EXT_VERSION("holiday") >= "0.1.3") {
		// Include only users with no active holiday
		$EXCLUDE_LIST .= " AND d.holiday_active='N'";
	} // END - if

	// Check for all accounts
	$result_inactive = SQL_QUERY_ESC("SELECT DISTINCT d.userid, d.email, d.last_online
FROM `{!_MYSQL_PREFIX!}_user_data` AS d
WHERE d.`status`='CONFIRMED' AND d.joined < (UNIX_TIMESTAMP() - %s) AND d.last_online < (UNIX_TIMESTAMP() - %s) AND d.ap_notified < (UNIX_TIMESTAMP() - %s)
".$EXCLUDE_LIST."
ORDER BY d.userid", array($since, $since, $since), __FILE__, __LINE__);

	if (SQL_NUMROWS($result_inactive) > 0) {
		// Prepare variables and constants...
		$UIDs = "";
		define('__INACTIVE_SINCE', (getConfig('ap_inactive_since') / 60 / 60));
		define('__INACTIVE_TIME' , (getConfig('ap_in_time')  / 60 / 60));

		// Mark found accounts as inactive and send an email
		while (list($uid, $email, $last) = SQL_FETCHROW($result_inactive)) {
			// Remember userids for the admin
			$UIDs .= $uid.", ";

			// Get date/time from timestamp
			$last = MAKE_DATETIME($last, "0");

			// Load mail template
			$msg = LOAD_EMAIL_TEMPLATE("member_autopurge_inactive", $last, bigintval($uid));
			SEND_EMAIL($email, AUTOPURGE_MEMBER_INACTIVE_SUBJECT, $msg);

			// Update this account
			SQL_QUERY_ESC("UPDATE `{!_MYSQL_PREFIX!}_user_data` SET ap_notified=UNIX_TIMESTAMP() WHERE userid=%s LIMIT 1",
				array(bigintval($uid)), __FILE__, __LINE__);
		} // END - while

		// Remove last comma
		$UIDs = str_replace(", ", "\n", substr($UIDs, 0, -2));

		// Send mail notification to admin
		SEND_ADMIN_NOTIFICATION(AUTOPURGE_ADMIN_INACTIVE_SUBJECT, "admin_autopurge_inactive", $UIDs, "");
	} // END - if

	// Free memory
	SQL_FREERESULT($result_inactive);

	// Now let's have a look for inactive accounts we want to delete we newly use the same exclude list
	// here for e.g. excluding holiday users
	$time = bigintval(getConfig('ap_in_time'));
	$result_inactive = SQL_QUERY_ESC("SELECT d.userid, d.email, d.last_online
FROM `{!_MYSQL_PREFIX!}_user_data` AS d
WHERE `status`='CONFIRMED' AND joined < (UNIX_TIMESTAMP() - %s) AND last_online < (UNIX_TIMESTAMP() - %s) AND ap_notified < (UNIX_TIMESTAMP() - %s)
".$EXCLUDE_LIST."
ORDER BY userid",
	 array($since, $since, $time), __FILE__, __LINE__);
	if (SQL_NUMROWS($result_inactive) > 0) {
		// Prepare variable...
		$UIDs = "";

		// Delete inactive accounts
		while (list($uid, $email, $last) = SQL_FETCHROW($result_inactive)) {
			// Remember userids for the admin
			$UIDs .= $uid.", ";

			// Get date/time from timestamp
			$last = MAKE_DATETIME($last, "0");

			// Finnaly delete this inactive account
			DELETE_USER_ACCOUNT(bigintval($uid), LOAD_EMAIL_TEMPLATE("member_autopurge_delete", $last, ""));
		} // END - while

		// Remove last comma
		$UIDs = str_replace(", ", "\n", substr($UIDs, 0, -2));

		// Send mail notification to admin
		if (getConfig('ap_in_notify') == "Y") {
			SEND_ADMIN_NOTIFICATION(AUTOPURGE_ADMIN_DELETE_SUBJECT, "admin_autopurge_delete", $UIDs, "");
		} // END - if
	} // END - if

	// Free memory
	SQL_FREERESULT($result_inactive);
} // END - if

//
?>
