<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 06/10/2005 *
 * ===============                              Last change: 05/18/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-sponsor_reg.php                             *
 * -------------------------------------------------------------------- *
 * Short description : Sponsor's registration form                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Anmeldeformular fuer Sponsoren                   *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software. You can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License.       *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4)."/security.php";
	require($INC);
} elseif ((!EXT_IS_ACTIVE("sponsor"))) {
	if (IS_ADMIN()) {
		addFatalMessage(sprintf(EXTENSION_PROBLEM_NOT_INSTALLED, "sponsor"));
	} else {
		addFatalMessage(EXTENSION_PROBLEM_EXT_INACTIVE, "sponsor");
	}
	return;
}

// Add description as navigation point
ADD_DESCR("guest", __FILE__);

// Create array for form errors (= missing data)
$FORM_ERRORS = array();

if (isset($_POST['ok'])) {
	//
	// Check submitted form data
	//
	// 1. Salutation / Surname / family name
	if (empty($_POST['gender'])) {
		// Surname is empty
		$FORM_ERRORS[] = SPONSOR_NO_GENDER_SELECTED;
	}

	if (empty($_POST['surname'])) {
		// Surname is empty
		$FORM_ERRORS[] = SPONSOR_SURNAME_IS_EMPTY;
	}

	if (empty($_POST['family'])) {
		// Surname is empty
		$FORM_ERRORS[] = SPONSOR_FAMILY_IS_EMPTY;
	}

	// 2. Company name
	// 012     3                 32    23      4                   43    3      4                  4321    12      3                 32    2     3                   3210
	if (((empty($_POST['company'])) && ((!empty($_POST['tax_ident'])) || (!empty($_POST['position'])))) || ((!empty($_POST['company'])) && (empty($_POST['tax_ident'])))) {
		if (empty($_POST['company'])) {
			// Company name is empty
			$FORM_ERRORS[] = SPONSOR_COMPANY_IS_EMPTY;
		} elseif (empty($_POST['tax_ident'])) {
			// Tax ident number name is empty
			$FORM_ERRORS[] = SPONSOR_TAX_IDENT_IS_EMPTY;
		}

		if (empty($_POST['position'])) {
			// Not fatal but not nice: position in company is empty
			$FORM_ERRORS[] = SPONSOR_POSITION_IS_EMPTY;
		}
	}

	// 3. Street and number
	if (empty($_POST['street_nr1'])) {
		// Street name and house number are empty
		$FORM_ERRORS[] = SPONSOR_STREET_NR1_IS_EMPTY;
	} elseif ((!empty($_POST['street_nr2'])) && (empty($_POST['street_nr1']))) {
		// 1st line for street is empty, but 2nd line not
		$FORM_ERRORS[] = SPONSOR_STREET_NR1_IS_EMPTY_2_NOT;
	}

	// 4. Country code
	if (empty($_POST['country'])) {
		// Country code is empty
		$FORM_ERRORS[] = SPONSOR_COUNTRY_IS_EMPTY;
	} elseif (strlen($_POST['country']) != 2) {
		// Country code is invalid
		$FORM_ERRORS[] = SPONSOR_COUNTRY_IS_INVALID;
	}

	// 3. ZIP code
	if (empty($_POST['zip'])) {
		// ZIP code is empty
		$FORM_ERRORS[] = SPONSOR_ZIP_IS_EMPTY;
	} elseif (bigintval($_POST['zip']) != $_POST['zip']) {
		// ZIP is invalid
		$FORM_ERRORS[] = SPONSOR_ZIP_IS_INVALID;
		$_POST['zip'] = "";
	}

	// 4. City
	if (empty($_POST['city'])) {
		// City is empty
		$FORM_ERRORS[] = SPONSOR_CITY_IS_EMPTY;
	}

	// 5. Phone number
	if (empty($_POST['phone'])) {
		// City is empty
		$FORM_ERRORS[] = SPONSOR_PHONE_IS_EMPTY;
	}

	// 6. Homepage URL
	if (empty($_POST['url'])) {
		// Homepage URL is empty
		$FORM_ERRORS[] = SPONSOR_URL_IS_EMPTY;
	} elseif (!VALIDATE_URL($_POST['url'])) {
		// Homepage URL is invalid
		$FORM_ERRORS[] = SPONSOR_URL_IS_INVALID;
		$_POST['url'] = "";
	}

	// 7. Light validation of email address
	if ((empty($_POST['email'])) || ($_POST['email'] == "@")) {
		// Email is invalid/empty
		$FORM_ERRORS[] = SPONSOR_EMAIL_IS_INVALID;
	} elseif (SPONSOR_FOUND_EMAIL_DB($_POST['email'])) {
		// Email already found in database!
		$FORM_ERRORS[] = SPONSOR_EMAIL_IS_ALREADY_REGISTERED;
		$_POST['email'] = "";
	}
	// 8. Pay type selected?
	if (empty($_POST['pay_type']))
	{
		// Not pay type selected
		$FORM_ERRORS[] = SPONSOR_NO_PAYTYPE_SELECTED;
	}
	// 9. Interval of mails
	if (empty($_POST['warning_interval']))
	{
		// No warning interval selected
		$FORM_ERRORS[] = SPONSOR_NO_WARNING_INTERVAL_SELECTED;
	}
	// 10. Mail notifications disabled/enabled
	if (empty($_POST['receive_warnings']))
	{
		// Option not selected!
		$FORM_ERRORS[] = SPONSOR_NO_RECEIVE_WARNINGS_SELECTED;
	}
	// Did he enter his password twice?
	if (((empty($_POST['pass1'])) || (empty($_POST['pass2']))) || (($_POST['pass1'] != $_POST['pass2']) && (!empty($_POST['pass1'])) && (!empty($_POST['pass2']))))
	{
		if (($_POST['pass1'] != $_POST['pass2']) && (!empty($_POST['pass1'])) && (!empty($_POST['pass2'])))
		{
			// Passwords missmatch
			$FORM_ERRORS[] = SPONSOR_PASSWORDS_MISMATCH;
		}
		 else
		{
			if (empty($_POST['pass1']))
			{
				// Password 1 is empty
				$FORM_ERRORS[] = SPONSOR_PASSWORD1_EMPTY;
			}
			if (empty($_POST['pass2']))
			{
				// Password 2 is empty
				$FORM_ERRORS[] = SPONSOR_PASSWORD2_EMPTY;
			}
		}
	}
	// Is the password long enough?
	 elseif (strlen($_POST['pass1']) < getConfig('pass_len'))
	{
		// Too short!
		$FORM_ERRORS[] = SPONSOR_PASSWORD_TOO_SHORT;
	}

	// Check if he has accepted the terms&conditions
	if (empty($_POST['terms'])) {
		// Homepage URL is empty
		$FORM_ERRORS[] = SPONSOR_TERMS_NOT_ACCEPTED;
	}
	
	// If there is something wrong/missing stop registration
	if (count($FORM_ERRORS) > 0) unset($_POST['ok']);
}

if ((isset($_POST['ok'])) && (count($FORM_ERRORS) == 0)) {
	// Generate message array
	$MSGs = array(
		'failed' => SPONSOR_REGISTRATION_FAILED,
		'added'  => SPONSOR_REGISTRATION_COMPLETED,
	);

	// Calulate points
	$result = SQL_QUERY_ESC("SELECT (pay_rate * pay_min_count) AS points, pay_min_count AS pay, pay_currency AS curr
FROM `{!_MYSQL_PREFIX!}_sponsor_paytypes`
WHERE id='%s' LIMIT 1", array($_POST['pay_type']), __FILE__, __LINE__);
	list($points, $pay, $curr) = SQL_FETCHROW($result);

	// Free memory
	SQL_FREERESULT($result);

	// Add points to array
	$_POST['points_amount'] = $points;
	$_POST['points_used']   = "0.00000";
	$_POST['last_pay']      = $pay;
	$_POST['last_curr']     = $curr;

	// Register sponsor but never ever update here!
	$STATUS = SPONSOR_HANDLE_SPONSOR($_POST, true, $MSGs, true);

	// Check the status of the registration process
	switch ($STATUS)
	{
	case "added": // Sponsor successfully added with account status = UNCONFIRMED!
		// Check for his ID number
		$result = SQL_QUERY_ESC("SELECT id, hash FROM `{!_MYSQL_PREFIX!}_sponsor_data` WHERE email='%s' LIMIT 1",
		 array($_POST['email']), __FILE__, __LINE__);
		if (SQL_NUMROWS($result) == 1)
		{
			// ID found so let's load it for the confirmation email
			list($id, $hash) = SQL_FETCHROW($result);

			// Prepare data for the email template
			define('__ID'       , $id);
			define('__HASH'     , $hash);
			define('__EMAIL'    , $_POST['email']);
			define('__SURNAME'  , $_POST['surname']);
			define('__FAMILY'   , $_POST['family']);
			define('__GENDER'    , TRANSLATE_GENDER($_POST['gender']));
			define('__TIMESTAMP', MAKE_DATETIME(time(), 0));
			define('__PASSWORD' , $_POST['pass1']);

			// Generate email and send it to the new sponsor
			$EMAIL_MSG = LOAD_EMAIL_TEMPLATE("sponsor_confirm", $hash);
			SEND_EMAIL($_POST['email'], SPONSOR_PLEASE_CONFIRM_SUBJ, $EMAIL_MSG);

			// Send mail to admin
			SEND_ADMIN_NOTIFICATION(ADMIN_NEW_SPONSOR, "admin_sponsor_reg", $hash);

			// Output message: DONE
			$MSG = $MSGs['added'];
		}
		 else
		{
			// Sponsor account not found???
			$MSG = SPONSOR_EMAIL_404_1.$_POST['email'].SPONSOR_EMAIL_404_2;
		}

		// Free memory
		SQL_FREERESULT($result);
		break;

	default:
		DEBUG_LOG(__FILE__, __LINE__, sprintf("Unknown status %s detected.", $STATUS));
		if (!IS_ADMIN()) {
			// Message for testing admin
			$MSG = ADMIN_SPONSOR_UNKOWN_STATUS_1.$STATUS.ADMIN_SPONSOR_UNKOWN_STATUS_2;
		} else {
			// Message for the guest
			$MSG = SPONSOR_UNKOWN_STATUS_1.$STATUS.SPONSOR_UNKOWN_STATUS_2;
		}
		break;
	}

	// Display message
	LOAD_TEMPLATE("admin_settings_saved", false, $MSG);
} else {
	// Check for payment types
	$result = SQL_QUERY("SELECT id, pay_name, pay_rate, pay_currency, pay_min_count
FROM `{!_MYSQL_PREFIX!}_sponsor_paytypes`
ORDER BY pay_name", __FILE__, __LINE__);
	if (SQL_NUMROWS($result) > 0) {
		// Load all types...
		$OUT = "<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"300\" class=\"left2 right2 top2\">\n";
		$SW = 2;
		while (list($id, $name, $rate, $curr, $min) = SQL_FETCHROW($result))
		{
			$OUT .= "<tr>
  <td class=\"bottom2 switch_sw".$SW."\" height=\"50\" style=\"padding-left: 2px; padding-right: 2px\">
    <input type=\"radio\" name=\"pay_type\" class=\"guest_normal\" value=\"".bigintval($id)."\" />&nbsp;".$name."<br />
    <div align=\"right\">(".$min." ".$curr." = ".TRANSLATE_COMMA($rate * $min)." {!POINTS!})</div>
  </td>
</tr>\n";
			$SW = 3 - $SW;
		}
		$OUT .= "</table>\n";
		define('__PAYMENT_LIST', $OUT);
		SQL_FREERESULT($result);

		// Check for invalid entries
		if (count($FORM_ERRORS) > 0)
		{
			// Some found... :-(
			define('__COMPANY'  , COMPILE_CODE($_POST['company']));
			define('__POSITION' , COMPILE_CODE($_POST['position']));
			define('__TAX_IDENT', COMPILE_CODE($_POST['tax_ident']));
			define('__SURNAME'  , COMPILE_CODE($_POST['surname']));
			define('__FAMILY'   , COMPILE_CODE($_POST['family']));
			define('__STREET1'  , COMPILE_CODE($_POST['street_nr1']));
			define('__STREET2'  , COMPILE_CODE($_POST['street_nr2']));
			define('__COUNTRY'  , COMPILE_CODE($_POST['country']));
			define('__ZIP'      , COMPILE_CODE($_POST['zip']));
			define('__CITY'     , COMPILE_CODE($_POST['city']));
			define('__PHONE'    , COMPILE_CODE($_POST['phone']));
			define('__FAX'      , COMPILE_CODE($_POST['fax']));
			define('__CELL'     , COMPILE_CODE($_POST['cell']));
			define('__EMAIL'    , COMPILE_CODE($_POST['email']));
			define('__URL'      , COMPILE_CODE($_POST['url']));

			// Check for gender selection
			switch ($_POST['gender'])
			{
			case "M": // Male
				define('__GENDER_M'  , " selected=\"selected\"");
				define('__GENDER_F'  , "");
				define('__GENDER_C'  , "");
				break;

			case "F": // Female
				define('__GENDER_M'  , "");
				define('__GENDER_F'  , " selected=\"selected\"");
				define('__GENDER_C'  , "");
				break;

			case "C": // Company
				define('__GENDER_M'  , "");
				define('__GENDER_F'  , "");
				define('__GENDER_C'  , " selected=\"selected\"");
				break;
			}

			// Check for receive_warnings
			switch ($_POST['receive_warnings'])
			{
			case "Y":
				define('__REC_Y'    , " selected=\"selected\"");
				define('__REC_N'    , "");
				break;

			case "N":
				define('__REC_Y'    , "");
				define('__REC_N'    , " selected=\"selected\"");
				break;
			}

			// Errors found
			$OUT = "<P align=\"center\">
  <strong><div class=\"guest_failed\">".SPONSOR_REGISTER_SOMETHING_MISSING.":</div></strong><br />
</P>
<ol>\n";
			foreach ($FORM_ERRORS as $error) {
				$OUT .= "<li>".$error."</li>\n";
			} // END - if

			$OUT .= "</ol><br />\n";
			define('__SPONSOR_FORM_ERRORS', $OUT);
			define('__SPONSOR_REFID', $_POST['refid']);
		} else {
			// None found, first call
			define('__COMPANY'  , "");
			define('__POSITION' , "");
			define('__TAX_IDENT', "");
			define('__GENDER_M'  , "");
			define('__GENDER_F'  , "");
			define('__GENDER_C'  , "");
			define('__SURNAME'  , "");
			define('__FAMILY'   , "");
			define('__STREET1'  , "");
			define('__STREET2'  , "");
			define('__COUNTRY'  , "");
			define('__ZIP'      , "");
			define('__CITY'     , "");
			define('__PHONE'    , "");
			define('__FAX'      , "");
			define('__CELL'     , "");
			define('__EMAIL'    , "");
			define('__URL'      , "");
			define('__REC_Y'    , "");
			define('__REC_N'    , "");

			// No errors found so far
			define('__SPONSOR_FORM_ERRORS', "");
		}

		// Prepare referal things
		if (!isset($_GET['refid'])) {
			// No referal link
			define('__SPONSOR_REFID', "0");
		} else 	{
			// Referal ID transmitted, we don't care here if it is right or not
			define('__SPONSOR_REFID', bigintval($_GET['refid']));
		}

		// Display registration form
		LOAD_TEMPLATE("guest_sponsor_reg");
	} else {
		// Nothing added so far
		LOAD_TEMPLATE("admin_settings_saved", false, SPONSOR_PAYMENT_LIST_IS_EMPTY);
	}

	// Free memory
	SQL_FREERESULT($result);
}

//
?>
