<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 09/09/2008 *
 * ================                             Last change: 09/09/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-refback.php                                 *
 * -------------------------------------------------------------------- *
 * Short description : Refback setup                                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Refback-Einstellungen                            *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} elseif (!IS_MEMBER()) {
	// User is not logged in
	LOAD_URL("modules.php?module=index");
} elseif ((!EXT_IS_ACTIVE("refback")) && (!IS_ADMIN())) {
	addFatalMessage(EXTENSION_PROBLEM_EXT_INACTIVE, "refback");
	return;
}

// Is the refback system enabled?
if (getConfig('refback_enabled') == "N") {
	// Output message
	LOAD_TEMPLATE("admin_settings_saved", false, getMessage('MEMBER_REFBACK_DISABLED'));
	// Abort here
	return false;
} // END - if

// Add description as navigation point
ADD_DESCR("member", __FILE__);

// Was the form submitted?
if ((isset($_POST['edit'])) && (isset($_POST['id']))) {
	// Okay, has the user entered some values?
	if (isset($_POST['percents'])) {
		// Revert german commta for testing
		$percents = REVERT_COMMA($_POST['percents']);

		// Validate percents
		if ((($percents >= getConfig('refback_min_perc')) || (round($percents) == 0)) && ($percents <= getConfig('refback_max_perc'))) {
			// Change ref-back for this direct id
			$status = REFBACK_CHANGE_MEMBER_PERCENTS($_POST['id'], $_POST['percents']);

			// Check status
			if (isset($status['ok'])) {
				// No message found
				LOAD_TEMPLATE("admin_settings_saved", false, getMessage('MEMBER_REFBACK_DONE'));
			} elseif (isset($status['message'])) {
				// Something went wrong with error message
				LOAD_TEMPLATE("admin_settings_saved", false, sprintf(getMessage('MEMBER_REFBACK_ERROR_MESSAGE'), $status['message']));
			} else {
				// No message found
				LOAD_TEMPLATE("admin_settings_saved", false, getMessage('MEMBER_REFBACK_ERROR_EMPTY_MESSAGE'));
			}
		} else {
			// Percents out-of-bounds ;-)
			LOAD_TEMPLATE("admin_settings_saved", false, sprintf(getMessage('MEMBER_REFBACK_ERROR_OUT_OF_BOUNDS'), getConfig('refback_min_perc'), getConfig('refback_max_perc')));
		}

		// Insert line
	} else {
		// Read data from refback table
		$content = GET_USER_REF_ENTRY($_POST['id']);

		// Translate comma
		$content['refback'] = TRANSLATE_COMMA($content['refback']);
		$content['min']     = TRANSLATE_COMMA(getConfig('refback_min_perc').".0");
		$content['max']     = TRANSLATE_COMMA(getConfig('refback_max_perc').".0");

		// Load form for editing
		LOAD_TEMPLATE("member_refback_edit", false, $content);
	}
} // END - if

// Load all referal levels
$result = SQL_QUERY_ESC("SELECT r.level, r.percents
FROM `{!_MYSQL_PREFIX!}_refdepths` AS r
WHERE r.level > 0
ORDER BY r.level ASC",
	array($GLOBALS['userid']), __FILE__, __LINE__);

// Are there some entries? (Shall be!)
if (SQL_NUMROWS($result) > 0) {
	// List all levels
	$OUT = "";
	while ($content = SQL_FETCHARRAY($result)) {
		// Init variables
		$rows = "";
		$counter = 0;
		$SW = 2;

		// Check for users ref in this level
		foreach (GET_USER_REFS($GLOBALS['userid'], $content['level']) as $refRow) {
			// Not-deleted account is default
			$deleted = false;
			if (is_null($refRow['status'])) $deleted = true;

			// Add/"translate" more content
			$refRow['sw']      = $SW;
			$refRow['points']  = TRANSLATE_COMMA($refRow['points']);
			$refRow['refback'] = TRANSLATE_COMMA($refRow['refback']);
			$refRow['status']  = TRANSLATE_STATUS($refRow['status']);
			if (empty($refRow['nickname'])) $refRow['nickname'] = "---";

			// Load row template
			if ($deleted) {
				$rows .= LOAD_TEMPLATE("member_refback_list_row_deleted", true, $refRow);
			} else {
				$rows .= LOAD_TEMPLATE("member_refback_list_row", true, $refRow);
			}

			// Count this ref and switch color
			$counter++;
			$SW = 3 - $SW;
		} // END - foreach

		// Remember the content
		$content['counter']  = TRANSLATE_COMMA($counter);
		$content['percents'] = TRANSLATE_COMMA($content['percents']);
		$content['rows']     = $rows;

		// Load level template
		$OUT .= LOAD_TEMPLATE("member_refback_list_level", true, $content);
	} // END - while

	// Load main template
	LOAD_TEMPLATE("member_refback_list", false, $OUT);
} else {
	// No entries
	LOAD_TEMPLATE("admin_settings_saved", false, getMessage('MEMBER_REFBACK_NO_ENTRIES'));
}

// Free result
SQL_FREERESULT($result);

//
?>
